==> nextcloud-app-spreed-1%3A14.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/ast.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n convidáu/ada","%n convidaos/es"],
    "Guest" : "Convidáu/ada",
    "File is too big" : "El ficheru ye pergrande",
    "Invalid file provided" : "Apurrióse un ficheru non válidu",
    "Invalid image" : "Imaxe non válida",
    "Unknown filetype" : "Triba desconocida de ficheru",
    "An error occurred. Please contact your admin." : "Asocedió un fallu. Contauta col to alministrador, por favor.",
    "Andorra" : "Andorra",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Arxentina",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non válida, el formatu ha ser AAAA-MM-DD",
    "Leave call" : "Dexar llamada",
    "Limit to groups" : "Llendar a grupos",
    "Everyone" : "Toos",
    "Save changes" : "Guardar camudancies",
    "Saving …" : "Guardando...",
    "Saved!" : "¡Guardóse!",
    "None" : "Dengún",
    "User" : "Usuariu",
    "Disabled" : "Deshabilitáu",
    "Users" : "Usuarios",
    "Name" : "Nome",
    "General settings" : "Axustes xenerales",
    "Language" : "Llingua",
    "Country" : "País",
    "Status" : "Estáu",
    "Created at" : "Creóse a les",
    "Pending" : "Pendiente",
    "Error" : "Fallu",
    "TURN server protocols" : "Protocolos del sirvidor TURN",
    "OK" : "Aceutar",
    "Checking …" : "Comprobando...",
    "Copy link" : "Copiar enllaz",
    "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
    "Dismiss" : "Escartar",
    "Show your screen" : "Amosar la to pantalla",
    "Stop screensharing" : "Parar compartición de pantalla",
    "More actions" : "Más aiciones",
    "Mute audio" : "Silenciar audiu",
    "Disable video" : "Deshabilitar videu",
    "Enable screensharing" : "Activar compartición de pantalla",
    "Grid view" : "Vista de rexella",
    "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
    "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Usa un restolador distintu como Firefox o Chrome pa compartir la to pantalla, por favor.",
    "An error occurred while starting screensharing." : "Asocedió un fallu entrín s'aniciaba la compartición de pantalla.",
    "Back" : "Atrás",
    "You" : "Tu",
    "Favorite" : "Marcar como favoritu",
    "Description" : "Descripción",
    "Notifications" : "Notificaciones",
    "Password protection" : "Password protection",
    "Enter a password" : "Introduz una contraseña",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Desaniciar",
    "Password" : "Password",
    "API token" : "Pase d'API",
    "Login" : "Aniciu de sesión",
    "Nickname" : "Nomatu",
    "Client ID" : "ID de veceru",
    "Calls" : "Llamaes",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Protexer con contraseña",
    "Close" : "Zarrar",
    "Reply" : "Rempuesta",
    "Contact" : "Contautu",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "guest" : "invitáu",
    "No results" : "Ensin resultaos",
    "Add users or groups" : "Add users or groups",
    "Details" : "Detalles",
    "Settings" : "Settings",
    "Keyboard shortcuts" : "Atayos de tecláu",
    "Search" : "Search",
    "Send" : "Unviar",
    "Files" : "Ficheros",
    "Audio" : "Audiu",
    "Other" : "Otru",
    "Default" : "Predetermináu",
    "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
    "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
    "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
    "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
    "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "TURN server" : "Sirvidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "Saved" : "Guardóse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A15.0.2-2.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/ast.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n convidáu/ada","%n convidaos/es"],
    "Guest" : "Convidáu/ada",
    "File is too big" : "El ficheru ye pergrande",
    "Invalid file provided" : "Apurrióse un ficheru non válidu",
    "Invalid image" : "Imaxe non válida",
    "Unknown filetype" : "Triba desconocida de ficheru",
    "Andorra" : "Andorra",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Arxentina",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non válida, el formatu ha ser AAAA-MM-DD",
    "Leave call" : "Dexar llamada",
    "Limit to groups" : "Llendar a grupos",
    "Everyone" : "Toos",
    "Save changes" : "Guardar camudancies",
    "Saving …" : "Guardando...",
    "Saved!" : "¡Guardóse!",
    "None" : "Dengún",
    "User" : "Usuariu",
    "Disabled" : "Deshabilitáu",
    "Users" : "Usuarios",
    "Name" : "Nome",
    "General settings" : "Axustes xenerales",
    "Language" : "Llingua",
    "Country" : "País",
    "Status" : "Estáu",
    "Created at" : "Creóse a les",
    "Pending" : "Pendiente",
    "Error" : "Fallu",
    "TURN server protocols" : "Protocolos del sirvidor TURN",
    "OK" : "Aceutar",
    "Checking …" : "Comprobando...",
    "Copy link" : "Copiar enllaz",
    "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
    "Dismiss" : "Escartar",
    "Show your screen" : "Amosar la to pantalla",
    "Stop screensharing" : "Parar compartición de pantalla",
    "Mute audio" : "Silenciar audiu",
    "Disable video" : "Deshabilitar videu",
    "Enable screensharing" : "Activar compartición de pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
    "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Usa un restolador distintu como Firefox o Chrome pa compartir la to pantalla, por favor.",
    "An error occurred while starting screensharing." : "Asocedió un fallu entrín s'aniciaba la compartición de pantalla.",
    "Back" : "Atrás",
    "You" : "Tu",
    "Favorite" : "Marcar como favoritu",
    "Description" : "Descripción",
    "Personal" : "Personal",
    "Permissions" : "Permisos",
    "Password protection" : "Password protection",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Desaniciar",
    "Password" : "Password",
    "API token" : "Pase d'API",
    "Login" : "Aniciu de sesión",
    "Nickname" : "Nomatu",
    "Client ID" : "ID de veceru",
    "Notifications" : "Notificaciones",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Protexer con contraseña",
    "Close" : "Zarrar",
    "Reply" : "Rempuesta",
    "Contact" : "Contautu",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "Settings" : "Settings",
    "guest" : "invitáu",
    "No results" : "Ensin resultaos",
    "Add users or groups" : "Add users or groups",
    "Details" : "Detalles",
    "Keyboard shortcuts" : "Atayos de tecláu",
    "Search" : "Search",
    "Grid view" : "Vista de rexella",
    "Send" : "Unviar",
    "Files" : "Ficheros",
    "Polls" : "Enquestes",
    "Audio" : "Audiu",
    "Other" : "Otru",
    "Default" : "Predetermináu",
    "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
    "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
    "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
    "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
    "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "TURN server" : "Sirvidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "An error occurred. Please contact your admin." : "Asocedió un fallu. Contauta col to alministrador, por favor.",
    "Saved" : "Guardóse",
    "More actions" : "Más aiciones",
    "Enter a password" : "Introduz una contraseña",
    "Calls" : "Llamaes"
},
"nplurals=2; plural=(n != 1);");
